package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````0!P```````!``````````-@!`0``
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````#":````````,)H`````````
M``$```````$````&````@/L```````"`^P$``````(#[`0``````"`4`````
M```P!0```````````0```````@````8```"0^P```````)#[`0``````D/L!
M```````0`@```````!`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````0)(```````!`D@```````$"2````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````(#[````````@/L!``````"`^P$`
M`````(`$````````@`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`8-Q!/FSQ.IL+@]^-2/?_&(G=
M?D$$````$`````$```!'3E4```````,````'``````````$````!`````0``
M````````````````````````````````````````````````````````````
M``````,`"P#@%0````````````````````````,`%@````(`````````````
M````<0```!(`````````````````````````S0$``!(`````````````````
M````````>P```!(`````````````````````````>P$``!(`````````````
M````````````G`$``!(`````````````````````````/@(``!(`````````
M````````````````U`$``!(`````````````````````````AP```!(`````
M`````````````````````0```"``````````````````````````'P(``!(`
M````````````````````````&`(``!(`````````````````````````VP$`
M`!(`````````````````````````N0```!(`````````````````````````
M_@(``!$`````````````````````````80```!(`````````````````````
M````M0(``!(`````````````````````````YP```!(`````````````````
M````````*`(``!(`````````````````````````EP$``!(`````````````
M````````````Q0$``!(`````````````````````````I`$``!(`````````
M````````````````@@(``"(`````````````````````````$````"``````
M````````````````````W````!(`````````````````````````+````"``
M````````````````````````M0$``!(`````````````````````````V@(`
M`!(`````````````````````````6P(``!(`````````````````````````
MK@(``!(`````````````````````````=`(``!$`````````````````````
M````U`(``!(`````````````````````````4P```!(`````````````````
M````````)P$``!8`````````````````````````!`$``!(`````````````
M````````````6P$``!(`````````````````````````ZP$``!(`````````
M````````````````J````!(`````````````````````````]0```!(`````
M````````````````````IP(``!(`````````````````````````PP(``!(`
M````````````````````````[`(``!(`````````````````````````\0$`
M`!(`````````````````````````3`(``!(`````````````````````````
MS0```!(`````````````````````````A@$``!(`````````````````````
M````"0(``!(`````````````````````````F@```!(`````````````````
M````````(`$``!(`````````````````````````3P$``!(`````````````
M````````````6@(``!(`````````````````````````O`(``!(`````````
M````````````````GP(``!(`````````````````````````]@$``!(`````
M````````````````````K@$``!(`````````````````````````.@$``!(`
M````````````````````````D0(``!(`````````````````````````%`$`
M`!(``````````````````````````P(``!(`````````````````````````
M>P(``!(`````````````````````````1@```!$`````````````````````
M````=@```!(`````````````````````````P@```!(`````````````````
M````````;`$``!(`````````````````````````8@(``!(`````````````
M````````````X@(``!$`````````````````````````O@$``!(`````````
M````````````````Y`$``!(`````````````````````````,`(``!(`````
M````````````````````Y`(``!$`````````````````````````F`(``!(`
M`````````````````````````%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,
M7V1O7W5N9'5M<`!097)L7W-Y<U]T97)M`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7V9R964`4&5R;%]G971?<W8`4&5R;%]A=&9O<FM?=6YL;V-K`'!E<FQ?9&5S
M=')U8W0`4&5R;%]N97=84U]F;&%G<P!P97)L7W)U;@!097)L7VYE=UA3`%!E
M<FQ?<W9?<V5T<'9N`'!E<FQ?86QL;V,`4&5R;%]S=E]S971P=@!P97)L7V-O
M;G-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`4&5R;%]S869E<WES;6%L;&]C`%!,
M7V-U<G)E;G1?8V]N=&5X=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG
M7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<WES7VEN:70S`'!E<FQ?<&%R
M<V4`7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T
M<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`<W1R=&]K`&=E
M='!W=6ED`'-T<FQE;@!R;61I<@!R96%D`%]?;65M8W!Y7V-H:P!M:V1I<@!?
M7W9F<')I;G1F7V-H:P!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN
M=&9?8VAK`%]?;65M;6]V95]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?
M;&EB8U]S=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`
M<W1R8VAR`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T
M<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N
M`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN
M<V\N-2XT,`!L:6)C+G-O+C8`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`$=,24)#
M7S(N,3<`1TQ)0D-?,BXS-`!'3$E"0U\R+C,S```````````!``(``0`!``(`
M`@`"``$``0`"``(``@`!``,``0`"``$``@`"``(``@`"``$``0`!``(``@`$
M``(``@`"``$``0`!``$``@`!``$``@`"``(``@`"``$``@`"``$``@`!``0`
M`@`"``(``@`!``(``0`"``(``0`"``$``0`%``(``@`"``(``@`"```````!
M``$`*@,``!`````@````EY&6!@```P!``P````````$``P`@`P``$```````
M``"TD98&```%`$L#```0````LY&6!@``!`!6`P``$````)>1E@8```(`0`,`
M``````"`^P$```````,$````````8!T```````"(^P$```````,$````````
M#!T```````#X_P$```````,$`````````!H````````(``(```````,$````
M````"``"```````@``(```````,$````````@%0````````H``(```````,$
M````````$%$````````X``(```````,$`````````%(```````!```(`````
M``,$````````8%0```````!(``(```````,$````````:%0```````!0``(`
M``````,$````````<%0```````!8``(```````,$````````>%0```````!H
M``(```````,$````````2%0```````!P``(```````,$````````4%0`````
M``"```(```````,$````````B%0```````"8_P$```````$$```*````````
M``````"@_P$```````$$```+``````````````"H_P$```````$$```0````
M``````````"P_P$```````$$```8``````````````"X_P$```````$$```9
M``````````````#`_P$```````$$```;``````````````#(_P$```````$$
M```@``````````````#0_P$```````8$```C``````````````#8_P$`````
M``$$```D``````````````#@_P$```````$$```E``````````````#H_P$`
M``````$$```^``````````````#P_P$```````$$``!'``````````````"X
M_0$```````($```#``````````````#`_0$```````($```$````````````
M``#(_0$```````($```%``````````````#0_0$```````($```&````````
M``````#8_0$```````($```'``````````````#@_0$```````($```(````
M``````````#H_0$```````($```)``````````````#P_0$```````($```+
M``````````````#X_0$```````($```,````````````````_@$```````($
M```-```````````````(_@$```````($```.```````````````0_@$`````
M``($```/```````````````8_@$```````($```1```````````````@_@$`
M``````($```2```````````````H_@$```````($```3```````````````P
M_@$```````($```4```````````````X_@$```````($```5````````````
M``!`_@$```````($```6``````````````!(_@$```````($```7````````
M``````!0_@$```````($```8``````````````!8_@$```````($```:````
M``````````!@_@$```````($```<``````````````!H_@$```````($```=
M``````````````!P_@$```````($```>``````````````!X_@$```````($
M```?``````````````"`_@$```````($```A``````````````"(_@$`````
M``($```B``````````````"0_@$```````($```F``````````````"8_@$`
M``````($```G``````````````"@_@$```````($```H``````````````"H
M_@$```````($```I``````````````"P_@$```````($```J````````````
M``"X_@$```````($```K``````````````#`_@$```````($```L````````
M``````#(_@$```````($```M``````````````#0_@$```````($```N````
M``````````#8_@$```````($```O``````````````#@_@$```````($```P
M``````````````#H_@$```````($```Q``````````````#P_@$```````($
M```R``````````````#X_@$```````($```S````````````````_P$`````
M``($```T```````````````(_P$```````($```U```````````````0_P$`
M``````($```V```````````````8_P$```````($```W```````````````@
M_P$```````($```X```````````````H_P$```````($```Y````````````
M```P_P$```````($```Z```````````````X_P$```````($```[````````
M``````!`_P$```````($```\``````````````!(_P$```````($```]````
M``````````!0_P$```````($```_``````````````!8_P$```````($``!`
M``````````````!@_P$```````($``!!``````````````!H_P$```````($
M``!"``````````````!P_P$```````($``!$``````````````!X_P$`````
M``($``!%``````````````"`_P$```````($``!&``````````````"(_P$`
M``````($``!(```````````````?(`/5_7N_J?T#`)&B`0"4_7O!J,`#7]8`
M`````````/![OZGP``#0$=I&^1#"-I$@`A_6'R`#U1\@`]4?(`/5\```T!'>
M1OD0XC:1(`(?UO```-`1XD;Y$`(WD2`"'];P``#0$>9&^1`B-Y$@`A_6\```
MT!'J1OD00C>1(`(?UO```-`1[D;Y$&(WD2`"'];P``#0$?)&^1""-Y$@`A_6
M\```T!'V1OD0HC>1(`(?UO```-`1^D;Y$,(WD2`"'];P``#0$?Y&^1#B-Y$@
M`A_6\```T!$"1_D0`CB1(`(?UO```-`1!D?Y$"(XD2`"'];P``#0$0I'^1!"
M.)$@`A_6\```T!$.1_D08CB1(`(?UO```-`1$D?Y$((XD2`"'];P``#0$19'
M^1"B.)$@`A_6\```T!$:1_D0PCB1(`(?UO```-`1'D?Y$.(XD2`"'];P``#0
M$2)'^1`".9$@`A_6\```T!$F1_D0(CF1(`(?UO```-`1*D?Y$$(YD2`"'];P
M``#0$2Y'^1!B.9$@`A_6\```T!$R1_D0@CF1(`(?UO```-`1-D?Y$*(YD2`"
M'];P``#0$3I'^1#".9$@`A_6\```T!$^1_D0XCF1(`(?UO```-`10D?Y$`(Z
MD2`"'];P``#0$49'^1`B.I$@`A_6\```T!%*1_D00CJ1(`(?UO```-`13D?Y
M$&(ZD2`"'];P``#0$5)'^1"".I$@`A_6\```T!%61_D0HCJ1(`(?UO```-`1
M6D?Y$,(ZD2`"'];P``#0$5Y'^1#B.I$@`A_6\```T!%B1_D0`CN1(`(?UO``
M`-`19D?Y$"([D2`"'];P``#0$6I'^1!".Y$@`A_6\```T!%N1_D08CN1(`(?
MUO```-`1<D?Y$(([D2`"'];P``#0$79'^1"B.Y$@`A_6\```T!%Z1_D0PCN1
M(`(?UO```-`1?D?Y$.([D2`"'];P``#0$8)'^1`"/)$@`A_6\```T!&&1_D0
M(CR1(`(?UO```-`1BD?Y$$(\D2`"'];P``#0$8Y'^1!B/)$@`A_6\```T!&2
M1_D0@CR1(`(?UO```-`1ED?Y$*(\D2`"'];P``#0$9I'^1#"/)$@`A_6\```
MT!&>1_D0XCR1(`(?UO```-`1HD?Y$`(]D2`"'];P``#0$:9'^1`B/9$@`A_6
M\```T!&J1_D00CV1(`(?UO```-`1KD?Y$&(]D2`"'];P``#0$;)'^1""/9$@
M`A_6\```T!&V1_D0HCV1(`(?UO```-`1ND?Y$,(]D2`"'];P``#0$;Y'^1#B
M/9$@`A_6\```T!'"1_D0`CZ1(`(?UO```-`1QD?Y$"(^D2`"']8`````````
M```````````````````````````````````````````````````````_(P/5
M_X,!T>,``-!CU$?Y_7L#J?W#`)'BAP"IXB,`D>%#`)'@'P"YX',`D?-3!*GU
M6P6I9`!`^>07`/D$`(#2S/__E^(``-!"S$?YX```T`#P1_GA`P*JB@T`E.``
M`-``]$?Y``!`.6`)`#;@``#0`.A'^4'0.]7S``#P(FA@^/0?0+E!:%(Y@!(`
M$90.`!$A!``R06@2.0!\?9.A__^7XP,`JN8+0/GA``#P8D("D>`?0+DE0$#Y
M)```D,<`0/F$X!"19Q``J2$``)`A`!&10P0`^64$`:D?!`!Q+0D`5"$`@-(D
M#``1Q7AA^"$$`)%EV"3X'P`!:VS__U0`#``1=4("D7_8(/@!``"PX@,4*B$`
M$)$$`(#2H`Y`^<W^_Y<@!0`T=4("D?:3`)&@#D#Y5/__E_0#`"KA`Q:J(```
MD`!`!I&/``"40`0`M'-"`I%@#D#YL_[_EQK__Y?@``#0`-1'^>(70/D!`$#Y
M0@`!ZP$`@-+A!`!4_7M#J>`#%"KS4T2I]5M%J?^#`9&_(P/5P`-?UO/^_Y?S
M``#P8D("D4`,`/D@`P"T$O__E^```-``Z$?Y0=`[U2)H8/A?6"0YK___%Z`.
M0/G"_O^7UO__%Z`*0/E@``"TVP<`E-S__Q?A`Q:J(```D`!@!)%E``"4H`H`
M^<#Z_[33!P"4U/__%X``@%*___\7(`"`4L7^_Y<4__^7'R`#U1\@`]4?(`/5
M'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'0"`TAX`@-+E
M`P"JX0-`^>(C`)'F`P"1X```T`#\1_D#`(#2!`"`TD7__Y?0_O^7X```T`#0
M1_E```"TA/[_%\`#7]8?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]7@``#P`"`"
MD>$``/`A(`*1/P``Z\```%3A``#0(=Q'^6$``+3P`P&J``(?UL`#7];@``#P
M`"`"D>$``/`A(`*1(0``RR+\?]-!#(&+(?Q!D\$``+3B``#00N!'^6(``+3P
M`P*J``(?UL`#7]8_(P/5_7N^J?T#`)'S"P#Y\P``\&`B0CE``0`WX```T`#8
M1_F```"TX```\``$0/F%_O^7V/__ER``@%)@(@(Y\PM`^?U[PJB_(P/5P`-?
MUA\@`]5?)`/5V___%Q\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U3\C`]7]>[RI
MX@``T$+X1_G]`P"1\U,!J?=C`ZE8`$#YF`8`M/5;`JGW`P"J]@,!J@``0#D5
M`(!2'_0`<0080'HA`P!4$P-`^1,"`+2U?D"3]`,8JA\@`]4?(`/5'R`#U>(#
M%:KA`Q>JX`,3JF7^_Y>````U8&IU.!_T`'$@`@!4DXY`^//^_[7U6T*IX`,3
MJO-30:GW8T.I_7O$J+\C`]7``U_6]0,7JJ`>0#@?]`!Q!!A`>J'__U2U`A=+
MXO__%Y0"&,NU!@"1<P(5BY3^0Y/4`@"YX`,3JO5;0JGS4T&I]V-#J?U[Q*B_
M(P/5P`-?UA,`@-+F__\7'R`#U1\@`]4_(P/5_\,"T>(``-!"U$?YX2,`D?U[
M":G]0P*1\U,`^?,#`*I#`$#YXT<`^0,`@-*`_O^78`(`->$;0+D"`)12(0P4
M$C\00'$D$$)ZX`$`5.$``-`AU$?YXT=`^2(`0/EC``+K`@"`TL$!`%3S4T#Y
M_7M)J?_#`I&_(P/5P`-?U@``@%+S__\7X`,3JD$`@%(D_O^7'P``<>`7GQKM
M__\74/[_ES\C`]7_`P/1X0``T"'41_G]>PFI_4,"D2(`0/GB1P#Y`@"`TL``
M`+3S4PJI\P,`J@$`0#FA`0`U\U-*J>```-``U$?YXD=`^0$`0/E"``'K`0"`
MTD$)`%3]>TFI_P,#D;\C`]7``U_6]5L+J5#^_Y?T`P"JP`8`M.`#%*KH_?^7
MX`4`M`%,0#D53`"1/[@`<6$``%2A!D`Y`?__-`!,0#D?N`!QH`4`5.`#$ZIT
M_O^7]@,`JN`#%:IQ_O^7U@(`"]8*`!'6?D"3X`,6JBC^_Y?E`Q6JX@,6JN0#
M$ZH#``#P8Z`"D?4#`*I!`(!2:/[_E^$C`)'@`Q6JW?W_EQ\$`#&@``!4X!M`
MN0`,%!(?$$!Q``,`5.`#%:I]_?^7X`,5JD/^_Y?@`Q2JO?W_E\#Z_[4?(`/5
M'R`#U1\@`]7@`Q2JP_W_E^`#$ZK9_?^7\U-*J?5;2ZFZ__\7H`9`.1^X`'%!
M^O]4H`I`.8#X_S3/__\7X`,5JJ/__Y?I__\7\U,*J?5;"ZGN_?^7/R,#U?_#
M`=']>P&I_4,`D?-3`JGS`P"J]`,!JO5;`ZGW8P2I^6L%J>```+``U$?Y(0!`
M.0(`0/GB!P#Y`@"`TC_T`'&4%I2:X`,4JBK^_Y?V`P"JX1,`D>`#$ZH>__^7
MP`@`M/4#`*HC_O^7WP(`ZXD'`%3X!X"Y^0``L#G[1_D8\WW38`)`.1_T`'$$
M&$!Z@`P`5.0#$ZJ#'$`X?_0`<6080'JA__]4A``3RX1\0),U`T#YP`H`D0``
M!(O*_?^7H&HX^``#`+0A`T#YX`,3JB-H>/@!%$`X80``.3_T`'$D&$!Z(`$`
M5!\@`]4?(`/5'R`#U0(40#AB'``X7_0`<4080'J!__]4H0>`4@``@-)A%``X
M@FI@.&)H(#@`!`"1HO__->```+``U$?YX@=`^0$`0/E"``'K`0"`TJ$'`%3]
M>T&I\U-"J?5;0ZGW8T2I^6M%J?_#`9&_(P/5P`-?U@$`@-*":F$XHFHA."$$
M`)&B__\U[/__%_D``+`Y^T?Y^S,`^14`@%([`T#Y8`-`^<`$`+3@`QNJ`8Q`
M^.(#%2JU!@`1H?__M4(,`!%7?'V3X0``T""00+E``@`U(@"`4N`#%ZHBD`"Y
MA_W_E_H#`*I``P"TN'Y]D^,#%ZKA`QNJX@,8JOC\_Y<Z`P#YH`8`$?4'`+E?
MVR#X^S-`^:+__Q?A`Q>JX`,;JA?]_Y<@`P#Y^@,`JB`!`+2X?GV3]/__%P0`
M@-*C__\7%P*`TN'__Q?[,P#Y8/W_E_LS0/FZ__\7/R,#U?U[O:D-`H+2_0,`
MD?-3`:GU6P*I_V,MR_\#`OGU(P"1XP``L&/41_GS`P"J]`,!JN+_@=)@`$#Y
MX`<(^0``@-+A`Q6J````\`#``I'9_/^7'P``<<T``%0$!`!1X@,`*J#*9#A@
M`P`UQ`(`->```+``Z$?Y0]`[U>(#%*KA`Q.J8&A@^./\_Y?@``"P`-1'^>('
M2/D!`$#Y0@`!ZP$`@-)A`P!4#0*"TO]C+8OS4T&I]5M"J?U[PZB_(P/5P`-?
MUN(#!"H?(`/5'R`#U1\@`]56?$"3X`,5JN(#%JKA!8!27/W_ET#\_[3@``"P
M`.A'^430.]7C`Q:JX@,5JN$#$ZJ`:&#X%_W_E^#__Q<9_?^7/R,#U?U[OJDC
M``#P`0``\/T#`)%CX`>1\U,!J530.]7S``"P<^I'^>(``+!"[$?Y(0`#D8!J
M<_A*_?^7@&IS^`0``/#S4T&IA,`0D?U[PJB_(P/5XP,$J@(``+`!``#P0H`D
MD2&``Y$%`(!2W?S_%U\D`]7@``"P`.A'^430.]7B``"P0NQ'^2,``/`!``#P
M8^`'D8!H8/@A``.1,?W_%S\C`]7]>[VI#02$TOT#`)'S4P&I]5L"J?]C+<O_
M`P+YX```L`#41_GS(P"1%`"`T@$`0/GA#Q#Y`0"`TG7\_Y?D`P`J!0``\`,`
M`/"EX`.18P`$D2(`@M)!`(!2X`,3JBS]_Y<``H+2]F,@B^$#%JK@`Q.J`@""
MTF+\_Y?``?@W%00`$?,#`*JU?D"3X`,5JMC\_Y?T`P"JX```M'-^0)/C`Q6J
MX0,6JN(#$ZKE_/^7GVHS..```+``U$?YX@]0^0$`0/E"``'K`0"`TB$!`%0-
M!(32_V,MB^`#%*KS4T&I]5M"J?U[PZB_(P/5P`-?UK3\_Y<?(`/5'R`#U1\@
M`]5?)`/5O___%S\C`]7]>[NI#1*"TOT#`)'S4P&I]5L"J?]C+<O_`P+Y]0,`
MJN(``+!"U$?Y\P,!JN$3`)%``$#YX$<(^0``@-(```#P`&`$D>3]_Y?T`P"J
MX06`4N`#%:K$_/^7@`(`M.$#%:H```#P`*`$D:;^_Y?@`Q6JX0``L"'41_GC
M1TCY(@!`^6,``NL"`(#2(0X`5`T2@M+_8RV+\U-!J?5;0JG]>\6HOR,#U<`#
M7];@`Q.JIOS_EQ8``/#!X@21!_S_E_,#`*K@_/^T]V,(^?<C`I'X9PCY&```
M\!@C!9'Y:PCY&0``\#D#!9'Z;PCY'R`#U1\@`]4?(`/58`)`.>`&`#2T``"T
MX0,3JN`#%*J#_/^7``4`-.`#$ZJX_/^7`@0`T?H#`*IB`@*+?P("ZZ,``%0*
M```47_0?.'\"`NN```!40`!`.1^\`'%@__]4X`,3JJK\_Y?Z`P"JX`,5JJ?\
M_Y<``!J+``0`D1_\/_'(`@!4Y`,3JN8#%:KE`QFJXP,8J@(`@M)!`(!2X`,7
MJI_\_Y?A(P"1X`,7JA3\_Y>@```UX!M`N0`,%!(?($!QP`(`5,'B!)$``(#2
MR/O_E_,#`*K`^?^U]V-(^?AG2/GY:TCY^F](^:/__Q=4`P"T@`)`.1^X`'&@
M``!4$P``\#H`@-)S0@21V?__%X`&0#F@_?\T^O__%^`#%ZHA`(!2^_O_EP#]
M_S7A`Q>J````\`"@!)$Y_O^7X`,7JDC\_Y?W8TCY^&=(^?EK2/GZ;TCYCO__
M%Q,``/`Z`(#2<T($D</__Q?W8PCY^&<(^?EK"/GZ;PCY%OS_ES\C`]7]>[ZI
MX06`4OT#`)'S"P#Y\P,`JL/[_Y<?``#Q8`:`FO,+0/G]>\*HOR,#U2W\_Q<_
M(P/5_7N]J0T"@M+]`P"1_V,MR_\#`OGA``"P(=1'^2(`0/GB!PCY`@"`TF`&
M`+3U&PCY]0,`J@$`0#G!!0`T\Q,(^?07"/E&_/^7`@0`D?,#`*I?!$#Q"`<`
M5/0C`)'A`Q6JX`,4JI+[_Y=@!@#1@`(`BQ\`%.NH``!4!P``%!_T'S@?`!3K
M@```5`$`0#D_O`!Q8/__5.`#%*KA!8!2E/O_E^`$`+0?`!3K*`0`5.`#%*K_
M^_^7X0``L"'41_GC!TCY(@!`^6,``NL"`(#2(04`5/,32/D-`H+2]!=(^?4;
M2/G_8RV+_7O#J+\C`]7``U_6]1M(^>```+``U$?YX@=(^0$`0/E"``'K`0"`
MTD$#`%0```#P`$`$D0T"@M+_8RV+_7O#J+\C`]7A^_\7'P``.=___Q<``(#2
MW___%^```+``U$?YX@=(^0$`0/E"``'K`0"`TN$``%3S$TCY````\/072/D`
M0`21]1M(^>O__Q>K^_^7\Q,(^?07"/GU&PCYI_O_ES\C`]7_@P'1X```L`#4
M1_G]>P&I_4,`D?-3`JD4``#P\Q,`D?5;`ZF40@61]V,$J?DK`/GU``"PM?I'
M^0$`0/GA!P#Y`0"`TN$#$ZK@`Q2JVOS_ER`"`+2B`D#YXP>`N4`,`XL!!$#Y
M07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4JLK\_Y<@
M_O^U]0``L+7Z1_D4``#PE((%D>$#$ZK@`Q2JPOS_ER`"`+2B`D#YXP>`N4`,
M`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A`Q.JX`,4
MJK+\_Y<@_O^U]0``L+7Z1_D4``#PE*(%D>$#$ZK@`Q2JJOS_ER`"`+2B`D#Y
MXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A
M`Q.JX`,4JIK\_Y<@_O^U]0``L+7Z1_D4``#PE.(%D>$#$ZK@`Q2JDOS_ER`"
M`+2B`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``
MD:'__[7A`Q.JX`,4JH+\_Y<@_O^U]@``L-;Z1_D4``#PE0(&D>$#$ZK@`Q6J
M>OS_ER`"`+3"`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!
M!`#Y`"``D:'__[7A`Q.JX`,5JFK\_Y<@_O^U]@``L-;Z1_D5``#PM4(&D>$#
M$ZK@`Q6J8OS_ER`"`+3"`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#
MU0$(0/D!!`#Y`"``D:'__[7A`Q.JX`,5JE+\_Y<@_O^U]P``L/?Z1_D5``#P
MMF($D>$#$ZK@`Q:J2OS_ER`"`+3B`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?
M(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A`Q.JX`,6JCK\_Y<@_O^U^```L!C[
M1_D6``#PUX(&D>$#$ZK@`Q>J,OS_ER`"`+0"`T#YXP>`N4`,`XL!!$#Y07@C
M^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A`Q.JX`,7JB+\_Y<@_O^U
M^0``L#G[1_D7``#P^,(&D>$#$ZK@`QBJ&OS_ER`"`+0B`T#YXP>`N4`,`XL!
M!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A`Q.JX`,8J@K\
M_Y<@_O^U^0``L#G[1_D8``#P&`,'D>$#$ZK@`QBJ`OS_ER`"`+0B`T#YXP>`
MN4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A`Q.J
MX`,8JO+[_Y<@_O^U^0``L#G[1_D8``#P&*,$D>$#$ZK@`QBJZOO_ER`"`+0B
M`T#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'_
M_[7A`Q.JX`,8JMK[_Y<@_O^UX0,3J@```/``0`>1U?O_E^$#`*I@``"TX,(&
MD9S\_Y?A`Q.J````\`"@!Y'-^_^7X0,`JH```+0```#P```(D9/\_Y?A`Q.J
M````\`!`")'$^_^7X0,`JJ`"`+2@8@21B_S_E^```+``U$?YX@=`^0$`0/E"
M``'K`0"`TJ$"`%3]>T&I@`(&D?5;0ZD!``#P\U-"J2'@")'W8T2I^2M`^?^#
M`9&_(P/5>?S_%^$#$ZH```#P`(`(D:K[_Y?A`P"J(/W_M,""!I%Q_/^7YO__
M%USZ_Y<?(`/5'R`#U1\@`]4_(P/5_X,`T0```/#B``"P0M1'^>$3`)']>P&I
M_4,`D0"`!I%#`$#YXP<`^0,`@-*4^_^7``(`M```0#D?P`!Q!!A`>N`'GQKA
M``"P(=1'^>,'0/DB`$#Y8P`"ZP(`@-+A``!4_7M!J?^#`)&_(P/5P`-?U@``
M@%+T__\7.?K_ES\C`]7_`P71[`:`$ND``+`IU4?Y[0,$D?U[!ZG]PP&1ZP^`
M$NH``+!*Y4?YX8L0J>(#`*KCDQ&IXP,`D4$`@%+EFQ*IYY\`^>`'!*WB#P6M
MY!<&K>8?!ZTD`4#YY#<`^00`@-+D`P61Y),"J>T?`/GL+P@I0`%`^?Z#PCS_
M@\,\_@.`/?\'@#W^@X0\_X.%/!CZ_Y?@'X!2POG_EQ\@`]4_(P/5_7N]J?T#
M`)'S4P&I]5L"J?]#0-'_`P+Y_T,`T?\#`OGC0T"1X0``D"'41_GU`P`J0@"`
M4B0`0/ED!`#Y!`"`T@$`@-)^^?^7%@0`T>`#%NO!/D"2`#Q`DB!$@-K6`@#K
M1`8`5/,#`)'T``"PX0,6JN`#%2H"`(!2<?G_EQ\$`+'@!0!4`@&`TN$#$ZK@
M`Q4J(@"@\M[Y_Y<?!``QH`0`5`!\0),?'`#QJ0,`5``@`-%@`@"KHP``5!D`
M`!0`!`#1'P`3Z\,"`%0!`$#Y@@I`^5\``>M!__]4```3RP``%HOA``"0(=1'
M^>-#0)%D!$#Y(@!`^80``NL"`(#280(`5/]#`)'_0T"1\U-!J?5;0JG]>\.H
MOR,#U<`#7];60D#1WT)`L4'Z_U0``("2[?__%P```-``0`F1B?__EP```-``
M``F1AO__E[WY_Y<_(P/5_7N_J?T#`)&A^?^74/G_ET```+0``$#Y_7O!J+\C
M`]7``U_6'R`#U1\@`]4_(P/5_P,!T>$``)`AU$?Y_7L!J?U#`)'S4P*I]`,`
MJO5;`ZD5``#0MH()D2(`0/GB!P#Y`@"`TN`#%JKA$P"1Z/K_EX```+3S`P"J
M``!`.0`"`#7@``"0`-1'^>('0/D!`$#Y0@`!ZP$`@-)A!0!4_7M!J>$#%*J@
M@@F1\U-"J?5;0ZG_`P&1OR,#U:#[_Q?@`Q2JV_G_E_4#`*K@`Q.JV/G_E[4"
M`(NU"@"1X`,5JI#Y_Y?F`Q.JX@,5JD$`@%+D`Q2J\P,`J@4``-`#``#0I>`$
MD6,@!9'.^?^7X```D`#41_GB!T#Y`0!`^4(``>L!`(#2(0$`5/U[0:GA`Q.J
MX`,6JO-30JGU6T.I_P,!D;\C`]5^^_\7:OG_EQ\@`]4_(P/5_X,&T>(``+!"
M0`"1XT,!D42@`)']>Q2I_0,%D>$``)`AU$?Y\U,5J?2#`)%()$&I]5L6J?/C
M`)%&G$6I]V,7J?<#`*I>@,(\(`!`^>"?`/D``(#2G?Q`K>@G`JGU<P"111!`
M^>:?`ZD8``#01#1`^7YT`*WA`Q6J`&,$D60*`/F%"@#Y?PB`/8WZ_Y>```"T
M`0!`.?8#`*IA(P`U^6L8J?MS&:DF^?^7U?C_EZ`0`+0;`$#Y>Q``M.`#&ZJ(
M^?^7$_A_TW,&`)'@`Q.J0/G_EV0#0#GZ`P"J_`,3JOD#`*J$`@`T%@``T-;B
M"9'B`Q.JX`,:JD$`@%+C`Q:J?/G_EUH+`)&?`Q/K8`H`T8$CDYID'T`X,P`3
MRW,*`)%_`@'K<R*!FG,"`<MS`@"+!/[_-0```-#V8P&1```(D0,``!3`AD#X
MP`$`M.$#%:I<^O^7\P,`JF#__[0!`$`Y(?__-)?Z_Y?@_O\TX`,3JC#Y_Y?S
M`P"J@`$`M1\@`]63`D#Y,P$`M&`"0#D`#0`TX`,3JHOZ_Y?@"P`UDP9`^90B
M`)$S__^UX`,3JDWY_Y?T`P"JX`,9JDKY_Y>4`@`+E!(0$1P``-"4?D"3X`,4
MJ@#Y_Y?G`QFJY`,3JN(#%*J%`P61!@``T`,``-#&``J18R`*D?D#`*I!`(!2
M/?G_E^`#&:H!.(!2&OG_EQ\$`#&A``!4S_C_EP4`0+F_1`!Q`18`5.$#`I'@
M`QFJ\?C_E_,#`"J@```UX)-`N0`,%!(?$$!Q``@`5.```)``Y$?Y`@``T.,"
M0/GD`QFJ``!`^4)@"Y%!`(!2QOC_EQ8`@-+@``"0`-1'^>*?0/D!`$#Y0@`!
MZP$`@-)!'@!4_7M4J>`#%JKY:UBI^W-9J?-35:GU6U:I]V-7J?^#!I&_(P/5
MP`-?UM_X_Y=S(@"1^P,`JJ`#`+5@`D#Y(`$`M.$#%:K\^?^78```M`$`0#G!
M_O\U8`9`^7,B`)$@__^UH`&`TKCX_Y>\`8#2&P``T/H#`*KS`QRJ^0,`JGO#
M"9%D"H!2=O__%^`#$ZJ4(@"1Q?C_E_,#`*K@\O^TH/__%Q,`@-*>__\7Z_C_
MEQ/X?]-S!@"18___%_:;0+E^^/^7WP(`:\'W_U3@DT"Y`"``$A\`!W%!]_]4
MX`,4JIKX_Y?A`Q6J]@,`J@```-``P`R1T?G_E^$#`*H@#@"TX`)`^=?[_Y?[
M`P"JH`T`M.`#&ZK1^/^7^@,`JA\,`''-`0!4`'Q`DP$``-``$`#1(>`,D6`#
M`(N0^/^7X```-5\3`'$`$@!46A<`46#+>C@?O`!Q@!$`5.$#%:H5``#0H((&
MD;7Y_Y>@``"T``!`.1_``'$$&$!ZP0``5.`#&ZH!`(!2L?C_E_<#`"K@"0`U
MH((&D0$``-`AX`B1<OK_EYP#!9$7``#0]\(0D1H``-#N]_^76N,-D>8#`"KE
M`QRJYP,7JN0#&:KB`Q2JX`,6J@,``-!!`(!28Z`-D:/X_Y<1```4.?C_EP``
M0+D?1`!Q00(`5-WW_Y?W`P#Y<P8`$>8#`"KG`Q,JY0,<JN0#&:KC`QJJX@,4
MJN`#%JI!`(!2DOC_E^`#%JH!.(!2;_C_EQ\$`#&`_?]4X`,9JG/X_Y?A`Q:J
M`&,$D4?Z_Y?@`Q:J@O[_EV7__Q?@``"0`.1'^>0#&:KC`D#Y`@``T```0/E"
M8`J100"`4B#X_Y=:__\7=O[_E^```)``U$?YXI]`^0$`0/E"``'K`0"`TH$)
M`%3]>U2IX`,6JO-35:GU6U:I]V-7J?^#!I&_(P/5._C_%_L"0/F3__\7!/[_
ME_H#`*H`]O^W`2@`T0(`@%+@`Q<J^P,$D8WW_Y?@`Q<JX0,;JL(`@-+]]_^7
M'Q@`\0$&`%3A`T&Y`&"(4B!HJ'(_``!K`?3_5&$+0'D`J8A2/P``:X'S_U1!
MRP#1`@"`4N`#%RKS(P21>??_E^`#%RKA`Q.J`@6`TNGW_Y<?H`#Q@0,`5.8#
M$ZJ%`P61X@,4JN0#&:K@`Q:J!P``T`,``-#GP!"18V`-D4$`@%+_PP0Y._C_
MEZ[__Q?W!D#YE^[_M.`#%ZHR^/^7'PP`\0GN_U0`$`#1`0``T.`"`(LA``V1
M\_?_EQ\``'%[$Y>::/__%P```-``(`V1G?W_E]3W_Y?Y:QBI^W,9J='W_Y<_
M(P/5_T,!T0```-#B``"00M1'^0``!I']>P&I_4,`D?-3`JE4T#O5\P``D'/J
M1_GU6P.I]A,`D>$#%JKW(P#YE6IS^$,`0/GC!P#Y`P"`TJ+"0CFBQ@(Y`OG_
MEX```+0!`$`Y/\0`<4`+`%0/_/^7E6IS^.`#%:H!``#08P"`4B%`#I$B`(!2
M3O?_E_4#`*I@`0"TH0I`^0(``-"`:G/X0F`.D2$`0/E.]_^7H`I`^0$`0/D@
M#$"YX`FP-X!J<_@!``#08P"`4B&`#I$B`(!2]P``L#OW_Y?U`P"J8`$`M.$#
M%JH```#0`*`$D=WX_Y>A"D#YX@,`JB$`0/D`!P"T@&IS^#?W_Y>5:G/X(@"`
M4@$``-`AH`Z1X`,5J@'W_Y<"``#0X0,`JD(`#Y'@`Q6J+/?_EX)J<_CT0@*1
MX0,6J@```-``8`217\0".<7X_Y>`"@#Y\P,`JL`"`+0!.(!2X`,3JJOW_Y<!
M!``1/P0`<02(47J!!`!4X```D`#41_GB!T#Y`0!`^4(``>L!`(#2@0,`5/<C
M0/G]>T&I\U-"J?5;0ZG_0P&1OR,#U<`#7]:`!D#Y^_W_EX`*`/GS`P"JX/S_
MM0```-``(`^1A??_EP`$0#D`]?\TI?__%^)"`I'@`P&J001`^2$`0/GX^?^7
MQO__%X!J<_AB]_^7L/__%U#W_Y?W0@*1XP,`*N(#$ZH```#0`,`/D>$&0/DA
M`$#Y</?_ES\C`]7_PP#1X0``D"'41_G]>P&I_4,`D?-3`JGS`P"J````T"(`
M0/GB!P#Y`@"`T@"`!I'A$P"1@?C_ER`!`+0``$`Y'\``<0080'K@!Y\:?P(`
M\>$'GQH_``!JH0$`5.```)``U$?YX@=`^0$`0/E"``'K`0"`TD$$`%3]>T&I
M\U-"J?_#`)&_(P/5P`-?UF`"0#E@_O\TX`,3JAC[_Y?A!8!2]`,`JM'V_Y<?
M``#Q@`:`FC[W_Y<!``#0@@"`TB$`"I'>]O^7P/S_->```)``U$?YX@=`^0$`
M0/E"``'K`0"`TN$``%3]>T&IX`,3JO-30JG_PP"1OR,#U;GX_Q<']_^7'R`#
MU1\@`]4?(`/5'R`#U1\@`]4?(`/5XP``D&/41_D_(P/5_7N_J0'@`)']`P"1
M_T,*T14$`$_B`P"1EN0`;V4`0/GE1P'Y!0"`TO?E`&\$X`&16N0`;^,#`)$[
M?$!M/03!/'L[GPZ_!V!OO@=8;[P'2&]["R`N_5=(3_]76$_>'SI.>#N53KT?
M-D[_'S=.WA^\3K\?OT[Y'[Y.>(R?3#\`!.O!_?]4^1_`/4*@"9'XY0!OX:,!
MD?_[0*W]\T&M^^M"K2%``)$@@-@\(0#?//4?/&[?'[Y.(!P@;KX?O4Z='[Q.
M?!^[3A4<-6Y;'[I..A^Y3K8&86^U5D%/U1ZU3KD>.$XY@(`\7P`!Z\']_U0&
M)$"I)3./T@<@0:E%4*ORX3=`J21TG=(*$$#YPOQ;TP,!!\I"%`:J8P`)BBO]
M0M-C``C*(0`%BR$`"HMB0"*+0@`!"VMY":IN?4"2K0$%BT'\6]/,`0?*(10"
MJHP!!HHA``V+C`$'RNU#0:G#_$+3C`$(BV-X!JHA``P+:P$#RFL!`HI/_$+3
M+/Q;TVL!#LJM`06+C!4!JHP!#8MK`0>+BP$+"^)Y`JIO?$"28P`"RF,``8IM
M_5O3#`(%BV,`#\JM%0NJ8P`.BZT!#(LL_$+3[A-`^:T!`PN!>0&J)-NM\JS]
M6]-#``'*S@$%BXP5#:I"?$"2C`$.BV,`"XKNPT*I8P`"RF,`#XMO_4+3@P$#
M"^MY"ZHO?$"2(0`+RFS\6],A``V*S@$%BXP5`ZHA``_*C`$.BR$``HNB_4+3
M@0$!"T)X#:IL`0+*;GU`DHP!`XHM_%O3"P(%BXP!#LJM%0&JC`$/BZT!"XMO
M_$+3\!]`^:L!#`OC>0.J3WQ`DD(``\IL_5O30@`!B@T"!8N,%0NJ0@`/RHP!
M#8M"``Z++?Q"TX(!`@OP(T#YH7D!JFP``<IN?$"2C`$+BDW\6],#`@6+C`$.
MRJT5`JJ,`0^+K0$#BV_]0M/P)T#YHP$,"^MY"ZHO?$"2;/Q;TR$`"\H-`@6+
M(0`"BHP5`ZHA``_*C`$-BTW\0M.B>0*J(0`.BX$!`0ML`0+*;GU`DHP!`XJ,
M`0[*+?Q;TXP!#XNM%0&J\#]%J0L"!8MP_$+3`WH#JJT!"XM0?$"20@`#RJL!
M#`M"``&*0@`0RNT!!8ML_5O30@`.B^Y'1JF,%0NJC`$-BRW\0M."`0(+H7D!
MJFP``<IO?$"2C`$+BDW\6]/#`06+C`$/RJT5`JJ,`1"+K0$#BV/]0M.N`0P+
M:W@+JB,`"\HP?$"28P`"BL']6],L`@6+(10.JF,`$,HA``R+8P`/BTS\0M,A
M``,+@GD"JN-'1ZEL`0+*;WU`DHP!#HHM_%O3C`$/RJT5`:J,`1"+4'Q`DF,`
M!8NM`0.+P_U"TZT!#`MC>`ZJ0@`#RBP"!8NK_5O30@`!BFL5#:I"`!#*:P$,
MBT(`#XMO`0(++/Q"T^)'2*F!>0&J:P`!RFY\0))K`0V*[/U;TVL!#LJ,%0^J
M:P$0BS!\0))"``6+C`$"BZ+]0M.,`0L+0G@-JB$``LHK`@6+@_U;TR$`#XIC
M%`RJ(0`0RB$`#HMC``N+;0`!"^']0M/N2T#Y(7@/JDL``<JC_5O30GQ`DFL!
M#(IC%`VJ:P$"RLX!!8MR`1"+PT$CBXO]0M-Q`!(+;'D,JNY/0/DK``S*+_Y;
MTR%\0)+O%1&J:P$-BFL!`<K%`06+?@$"BZ)`+XM/`!X+I?U"T^Y30/FM>`VJ
M\/U;TV,`$HL0%@^JD@$-RE("`TK#`02+4@(!BV%`,(LP`!(+(_Y"T^M70/EE
M>!&J#OY;TZ,!!<K.%1"J0@`>BVL!!(MB``)*3$`LBV)!+HM1``P+X_U"T^M;
M0/EC>`^J+OY;TZ\``\K.%1&J(0`2B^$!`4IK`02++4`MBV%!+HLK``T+#_Y"
MT^Y?0/GP>1"J;_U;TT(`#(OO%0NJ;``0RH(!`DK.`02+14`EB\)!+XM>``4+
M+/Y"T^YC0/F,>1&JS_];TR$`#8OO%1ZJ#0(,RJ$!`4K-`02+(T`CBZ%!+XLQ
M``,+;?U"T^YG0/FK>0NJ+_Y;TT(`!8OO%1&JA0$+RJ(``DK.`02+34`PB\)!
M+XM2``T+Q?]"T^YK0/FE>!ZJ3_Y;TR$``XOO%1*J8P$%RF$``4K.`02++$`L
MB\%!+XLP``P+(_Y"T^YO0/EC>!&J#_Y;TT(`#8OO%1"JK0`#RJ(!`DK.`02+
M2T`KB\)!+XM1``L+3?Y"T^YS0/FM>1*J+_Y;TR$`#(OO%1&J;``-RH$!`4K.
M`02+)4`EB\%!+XLR``4+#/Y"T^YW0/F,>1"J3_Y;TT(`"XOO%1*JJP$,RF(!
M`DK.`02+0T`CB\)!+XM0``,+*_Y"T^Y[0/EK>1&J#_Y;TR$`!8OO%1"JA0$+
MRJ$``4K.`02++4`MB\%!+XLQ``T+1?Y"T^Y_0/FE>!*J+_Y;TT(``XOO%1&J
M8P$%RF(``DK.`02+3$`LB\)!+XM.``P+`_Y"T^^#0/EC>!"JT/U;TR$`#8L0
M%@ZJK0`#RJ$!`4KM`02+*T`KBZ%!,(LP``L++_Y"T^V'0/GQ>1&J#_Y;TT(`
M#(OO%1"J;``1RH(!`DJL`02+14`EBX)!+XM,``4+S_U"T^V+0/GN>0ZJC_U;
MTR$`"XOO%0RJ*P(.RF$!`4JK`02+(T`CBV%!+XLK``,+#_Y"T^V/0/GP>1"J
MT@$0RF_]6]-"``6+Y14+JD("`DJM`02+3T`QBX+]0M-,>`RJI4$EB[$`#PLA
M``.+`P(,RJ4`#XOMDT#Y8P`!2F']0M,B_EO3*W@+JD(4$:J/`0O*K0$$B^\!
M!4JB02*+_D$PBW)`+HOMOU*I3@`2"R/^0M/!_5O38W@1JB$4#JJE`02+30`2
MBZ%`(8MB`0/*,``>"T(`#4KM`02+0D`LBP7^6],A`!Z+I100JJ4`#8NL``(+
MPOU"T^V?0/E">`ZJ;@`"RH7]6]/!`0%*K0$$BR%`*XND%`RJ"_Y"TX0`#8MP
M>1"JCP`!"^6C0/E+`!"J`0(""FL!#(IK`0&JY/U;TX&;E]*$%`^J8>.Q\J4`
M`8MC02.+A``%BX7]0M.-``,+Y*=`^:QX#*H+`@RJA0$0"FL!#XJC_5O3:P$%
MJH0``8MC%`VJ8D$BBV,`!(OE_4+3Y*M`^:]X#ZIN``(+@@$/JN,!#`I"``V*
MR_U;TT(``ZIK%0ZJ@P`!BT5`,(MK`0.+L?U"TV(!!0OCKT#Y+7H-JNL!#:JD
M`0\*:P$.BD7\6]-C``&+:P$$JJ44`JID02R+I0`#B\O]0M/CLT#Y;GD.JJP`
M!`ND`0ZJQ0$-"H0``HJ+_5O3A``%JFL5#*IE``&+4/Q"TX-`+XMK`06+!'H"
MJN6W0/EP`0,+RP$$JH(`#@IK`0R*`_Y;TZ4``8MK`0*J8Q00JF)!+8MC``6+
MB_U"T^6[0/EL>0RJ;P`""X(`#*J#`00*0@`0BNO]6]-"``.J:Q4/JJ,``8L-
M_D+314`NBVL!`XNB>1"JX[]`^6T!!0N+`0*J3@`,"FL!#XJE_5O3:P$.JF,`
M`8NE%`VJ9$$DBZ4``XOK_4+3X\-`^6]Y#ZJN``0+1``/JN4!`@J$``V*R_U;
MTX0`!:IK%0ZJ90`!BVL!!8N#0"R+L/U"TVP!`PODQT#Y#7H-JNL!#:JE`0\*
M:P$.BH/]6]-K`06JA``!BV,4#*K%_4+3KG@.JF)!(HMC``2+Q0$-"F,``@NB
M`0ZJ0@`,BI#]0M-"``6J:_Q;TT5`+XMK%0.JY#]9J0QZ#*J$``&+[P$!BVL!
M!(N$`0X*8@$%"\L!#*IK`0.*1?Q;TVL!!*JE%`*J9$$MBZ4`#XMK_$+3[=-`
M^:\`!`ME>0.J4/Q"TX0!!:JC``P*A``"BNO]6].M`0&+A``#JFL5#ZJ#0"Z+
M:P$-BP1Z`JIN`0,+JP`$JH(`!0IK`0^*:P$"JL/]6]-B02R+8Q0.JNVS6JGK
M_4+3K0$!BXP!`8MC``V+;0`""V-Y#ZJ"``.J<``$"D(`#HJK_5O3S_U"TT(`
M$*IK%0VJ14`EBVL!#(OB>0ZJ;P$%"VL``JI.``,*:P$-BFL!#JKE_5O39$$D
MBZ44#ZKLKUNIC`$!BVL!`8NE``R+K/U"TZX`!`N->0VJ10`-JK`!`@JE``^*
MQ/U;TZ4`$*KL_4+3A!0.JH]Y#ZJC0".+A``+B^7G0/F,``,+I`$/JNL!#0J$
M``Z*@_U;TX0`"ZJE``&+@D`BBV,4#*K$_4+38P`%BX5X#JIK``(+XP$%JJX`
M#PIC``R*8OU;TV,`#JI"%`NJ<D`MBX/]0M/D-UVI;'@,JHX!!0J$``&+H0$!
MBX)`(HND``RJ4``2"X0`"XJ$``ZJ`_Y;TY%`+XMC%!"J(T`CBV']0M-D`!$+
M*W@+JH\!"\I!`!*+COQ;TV,`$8O"%02J[@$!2L5!)8O!.IC2[3M>J4%,N?(/
M_D+3\'D0JG$!$,HC`@-*K0$!B\X!`8NB02*+;$`LBTT`!0M"``6+K_U;T^\5
M#:K#02^+C_Q"TWX`#`OD>02J[OM`^<__6],%`@3*[Q4>JJ(``DK%`0&+2T`K
MBZ)`+XM2``L+I?U"T^[_0/FM>`VJ3_Y;TX4`#<KO%1*J8P`,B\X!`8NC``-*
M94`PB\-!+XMQ``4+S/]"T^X#0?F,>1ZJ+_Y;TT(`"XOO%1&JJP$,RF(!`DK.
M`0&+1$`DB\)!+XM0``0+2_Y"T^X'0?EK>1*J#_Y;TV,`!8OO%1"JA0$+RJ,`
M`TK.`0&+;4`MB\-!+XMR``T+)?Y"T^X+0?FE>!&J3_Y;TT(`!(OO%1*J9`$%
MRH(``DK.`0&+3$`LB\)!+XM1``P+!/Y"T^X/0?F$>!"J+_Y;TV,`#8OO%1&J
MK0`$RJ,!`TK.`0&+:T`KB\-!+XMP``L+3?Y"T^X30?FM>1*J#_Y;TT(`#(OO
M%1"JC``-RH(!`DK.`0&+14`EB\)!+XM2``4++/Y"T^X70?F,>1&J3_Y;TV,`
M"XOO%1*JJP$,RF,!`TK.`0&+9$`DB\-!+XMQ``0+"_Y"T^X;0?EK>1"J+_Y;
MTT(`!8OO%1&JA0$+RJ(``DK.`0&+34`MB\)!+XM0``T+1?Y"T^X?0?FE>!*J
M#_Y;TV,`!(OO%1"J9`$%RH,``TK.`0&+;$`LB\-!+XMR``P+)/Y"T^XC0?F$
M>!&J3_Y;TT(`#8OO%1*JK0`$RJ(!`DK-`0&+2T`KBZ)!+XM1``L+#?Y"T^XG
M0?FP>1"J+_Y;TV,`#(OO%1&JC``0RH,!`TK,`0&+94`EBX-!+XM^``4+3?Y"
MT^PK0?FM>1*JSO];TT(`"XO.%1ZJ"P(-RF(!`DJ+`0&+1$`DBV)!+HM,``0+
M*_Y"T^\O0?EQ>1&JCOU;TV,`!8O.%0RJI0$1RJ4``TKC`0&+LD`PBVY`+HO%
M`1(+R_]"T^,S0?EK>1ZJK_Q;TS`""\I"``2+Y!4%J@("`DIC``&+7D`MBV)`
M)(M#`!X+A/U"T^\W0?F,>`RJ9/Q;TW`!#,K.`1*+A!0#JA`"#DKN`0&+$4(Q
MB\1!)(OO.T'YC@`1"ZW\0M.$`!&+K7D%JD4`'HN0`0W*POU;TQ`"!4I"%`ZJ
MY0$!BPM"*XM"``6+9?Q"T^\_0?E"``L+HW@#JLQ`+(NE`0/*2_Q;TV85`JJD
M``1*X0$!B\7]0M.$``&+Q@`,BZ%X#JJE`0H+R@``\$K51_E"``D+(0`'"V,`
M"`N$``8+!`@`J0$,`:D%$`#YXD=!^4$!0/E"``'K`0"`TJ$``%3_0PJ1_7O!
MJ+\C`]7``U_6R_+_EQ\@`]4?(`/5/R,#U?U[OZD`$(#2_0,`D=#R_Y<B``"P
M(0``L!\8`/E=B,`](@``L#Z$P#T?>`"Y7XS`/1YT`*T?"(`]_7O!J+\C`]7`
M`U_6/R,#U?U[NZE"?$"3_0,`D?-3`:GT`P"J]5L"J17@`)'W8P.I]P,"JO@#
M`:H%C$*I`'A`N:0,`@N_``3K8Y2#FF)T0HN$B@*IP`0`-?_^`'$M`P!4]GX&
M4_DC`/G9!@!1\P,8JM9F&E,6`Q:+'R`#U1\@`]4?(`/5?7)`K>`#%*I_>D&M
M<P(!D;UR`*V_>@&MDOO_EW\"%NL!__]4&`,!D0`(@%+W`@%1]QH92SACH)OY
M(T#YX0,8JN`#%:KB?D"3*O+_EY=Z`+GS4T&I]5M"J?=C0ZG]>\6HOR,#U<`#
M7]83"(!2<P(`2W\"%VN@PB"+<]*7&G9^0)/B`Q:J&_+_EX!Z0+E@`@`+@'H`
MN1\``7'!_?]4]P(32Q@#%HO@`Q2J;OO_E\K__Q<_(P/5_7N\J>,/@!+]`P"1
M\U,!J?0#`*KS`P&J]5L"J3;@`)'O&P#]-8!"J:(B`U,/`&>>000`$2!\0)/#
MRB(XP`(`BS_@`'%M"P!4`@B`4D(``4L!`(!20GQ`DZWR_Y?@`Q.J4_O_EQ\$
M`$]_@H,\W_X`K7\V`/GZ!7!__P5H?_L%>'^^`F>>X`,3JMP':'_=!W!_7P<#
M;MX'>']_!P5N_P4';I\'"6Z_!PMNWP<-;K\>#TY_.@#]/OO_EV$"0/G@`Q.J
M(?Q8TX$"`#EA`D#Y(?Q0TX$&`#EA`D#Y(?Q(TX$*`#EA`D#Y@0X`.6$&0/DA
M_%C3@1(`.6$&0/DA_%#3@18`.6$&0/DA_$C3@1H`.6$&0/F!'@`Y80I`^2'\
M6-.!(@`Y80I`^2'\4-.!)@`Y80I`^2'\2-.!*@`Y80I`^8$N`#EA#D#Y(?Q8
MTX$R`#EA#D#Y(?Q0TX$V`#EA#D#Y(?Q(TX$Z`#EA#D#Y@3X`.6$20/DA_%C3
M@4(`.6$20/DA_%#3@48`.6$20/DA_$C3@4H`.6$20/F!3@`Y[QM`_?-30:GU
M6T*I_7O$J+\C`]4\\O\7`@>`4D(``4L!`(!20GQ`DU/R_Y>L__\7'R`#U<,`
M`/!C!$#YYO'_%Q\@`]7]>[^I_0,`D?U[P:C``U_6`0`"```````E<R\E<P``
M`"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M`````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO
M)7,``````"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-10``
M```Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``````````4$52
M3$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`
M4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````
M````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!
M4E]'3$]"04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/
M0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!L<V5E
M:R!F86EL960`````<F5A9"!F86EL960``````$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!0051(`````'!A<FP`````+G!A<@````!S:&]R="!R96%D
M````````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S```````````8`````````'!E<FP`````,`````````!005(Z
M.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P```%5N86)L92!T;R!C<F5A=&4@
M8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M```````M90```````"TM````````55-%4@````!54T523D%-10``````````
M5$U01$E2``!414U01$E2`%1%35``````5$U0```````O=&UP`````&5V86P@
M)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C
M(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P
M;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?
M;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB
M.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE
M7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"([
M"GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H
M=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@
M)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK
M7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H
M=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@
M,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?
M34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I
M*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?
M<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT
M("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I
M;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@
M)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@
M?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D[
M"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A
M=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7
M:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U
M=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E
M;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N
M;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q
M6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T
M('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'
M24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII
M9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC
M('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL
M87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO
M;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L
M("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(
M12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R
M:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K
M97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S
M971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S
M*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F
M<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY
M("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE
M("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D
M8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D[
M"FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@
M*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@
M/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W
M-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL
M96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL
M97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.
M5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C
M<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R
M:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[
M8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL
M96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*
M?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L
M92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ
M<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P
M<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL
M(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY
M($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE
M7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@
M(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV
M("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]
M('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U
M<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^
M("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E
M<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*
M=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*
M)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S
M:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*
M?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q
M(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A
M;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G
M5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM
M>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%
M35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`
M861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL
M93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$[
M"GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@
M<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H
M+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z
M:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A
M<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R
M(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D
M8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@
M82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S
M92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I
M92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM
M;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE
M9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R
M+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]
M('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D
M(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`
M:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z
M.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB
M7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@
M*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD
M969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI
M*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<
M12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S
M=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII
M9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M
M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L*
M*"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]
M"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E
M;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@
M+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&
M24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT
M(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO
M<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M
M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I
M("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U
M=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N
M(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&
M:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D
M;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE
M;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$
M:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D
M9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X
M+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@
M>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E
M="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP
M86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T[
M"F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I
M;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005([
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I
M;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/
M.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R
M8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O
M<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL
M960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&
M:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D
M<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q
M,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN
M(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R
M;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H
M;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]
M"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\
M/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;
M("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP
M;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD[
M"GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]
M($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*
M<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I
M('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$
M>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR
M97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*
M<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N
M=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ
M2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:
M;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(
M03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!0
M05(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB
M=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I
M;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@
M<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I
M<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@
M4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U
M:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I
M('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H
M("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$
M25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@
M/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H
M)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO
M9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE
M(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%
M?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@
M(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M
M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H
M)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*
M96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G
M:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F
M:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<
M,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H
M(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H
M+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP
M0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F
M+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D
M:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C
M:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,
M14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D
M:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V
M95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@
M)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U
M;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D
M9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@
M)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R
M('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP
M;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L
M;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA
M;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I
M('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES
M>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y
M<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA
M;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII
M9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O
M9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD
M969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P
M=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1
M)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*
M?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I
M('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!4
M14U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)0
M05)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B
M?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,
M14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L
M;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B
M0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S
M:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]
M+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L
M:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E
M(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@
M0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F
M:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D
M<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`
M(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC``````````!#04-(10```2-%
M9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````````````
M`1L#.PP!```@````P(?__]0&````BO__)`$``&"*__\X`0``D(K__TP!``#,
MBO__8`$``""+__^(`0``0(O__Z`!``!`C/__"`(``.2,__\T`@``;([__XP"
M``"LD/__X`(``,"1__\8`P``,)+__T`#``!@DO__5`,``&"3__^,`P``:)/_
M_Z`#``#,E?__#`0```"6__\T!```B)?__Z@$``#`G/__Z`0``$"=__\0!0``
MX)W__RP%```PG___<`4``&"?__^4!0``@*#__]@%``#@IO__9`8```2I__^<
M!@``(*K__P@'````N___.`<``$B[__]<!P``<+S__YP'``!`OO__V`<`````
M```0``````````%Z4@`$>!X!&PP?`!`````8````U(C__S0`````00<>$```
M`"P````@B?__,``````````0````0````#R)__\\`````````"0```!4````
M9(G__U``````02U!#B"=!)X#0I,"3M[=TPX`02T````4````?````)")__\(
M``````````````!D````E````)B)___X`````$$M00Y`G0B>!T63!I0%EP*8
M`4.6`Y4$6=;51-[=U]C3U`X`02U!#D"3!I0%E026`Y<"F`&=")X'+4[6U4/>
MW=?8T]0.`$$M00Y`DP:4!9<"F`&=")X'+2@```#\````,(K__Z0`````02U!
M#K`!1)T$G@-"DP)6"M/=W@X`02U!"P``5````"@!``"HBO__B`$```!!+4$.
MP`%#G0:>!4:4`Y,$1-332=W>#@!!+4$.P`&3!)0#G0:>!2U!E@&5`GD*U--!
MUM5!"TG3U-76090#DP1!E@&5`@```%````"``0``V(O__T`"````02U!#G!!
MG0R>"T*3"I0)3I4(E@>7!I@%F02:`P)#"MG:U]C5UM/4W=X.`$$M00M)FP)>
M"MM!"TC;0IL"0MM!FP)"VS0```#4`0``Q(W__Q0!````02U!#C"=!IX%10[`
M(),$E`.5`I8!90H.,$/>W=76T]0.`$$M00L`)`````P"``"@CO__<`````!!
M+4$.()T$G@-%DP*4`4W>W=/4#@!!+1`````T`@``Z([__S``````````-```
M`$@"```$C___]`````!!+4$.,)T&G@5%#M!`DP24`Y4"E@%O"@XP1-[=U=;3
MU`X`02U!"P`0````@`(``,R/__\(`````````&@```"4`@``P(___V0"````
M02U!#E"="IX)10[@(9,(E`>5!I8%7PH.4$/>W=76T]0.`$$M00M(EP1"F`-#
MF0)#F@%W"M=!V$'90=I!"U8*UT'80=E!VD$+1-?8V=I!EP1!F`-!F0)!F@$`
M`"0``````P``N)'__S0`````02U!#B"=!)X#0Y,"1M[=TPX`02T```!P````
M*`,``,21__^(`0```$$M00XPG0:>!4,.P"!(E0)$DP1!E`-DTT+40=5!#C!!
MWMT.`$$M00[`()4"G0:>!2U!U4L.,$'>W0X`02U!#L`@DP24`Y4"G0:>!2U,
M"M-"U$+500M!T]3509,$090#094"`#P```"<`P``V)+__RP%````02U!#F!#
MG0J>"4*3")0'1I4&E@67!)@#F0(#,@$*V=?8U=;3U-W>#@!!+4$+```D````
MW`,``-"7__^``````$$M00X@19T"G@%4"MW>#@!!+4$+````&`````0$```H
MF/__G`````!!+4$.P`)%G1J>&4`````@!```K)C__U`!````02U!#C"=!IX%
M1`ZP@`23!)0#E0*6`4(.P(`$>@H.L(`$00XP0][=U=;3U`X`02U!"P``(```
M`&0$``"XF?__*`````!!+4$.$)T"G@%&WMT.`$$M````0````(@$``#$F?__
M'`$```!!+4$.0$.=!IX%0I,$E`-"E0*6`5D*U=;3U-W>#@!!+4$+8`K5UM/4
MW=X.`$$M00L```"(````S`0``*":__]@!@```$$M00Z@`T6=#)X+1),*E`E&
ME0B6!Y<&F`58F@.9!$&<`9L"`GP*VME!W-M$U]C5UM/4W=X.`$$M00L"E=G:
MV]Q.U]C5UM/4W=X.`$$M00Z@`Y,*E`F5")8'EP:8!9D$F@.;`IP!G0R>"RT"
M0]G:V]Q!F@.9!$&<`9L"`#0```!8!0``=*#__R0"````02U!#E!%G0B>!T*3
M!I0%1)4$E@-#EP("6@K7U=;3U-W>#@!!+4$+-````)`%``!@HO__!`$```!!
M+4$.,$.=!)X#0I,"E`%;"M/4W=X.`$$M00M:"M/4W=X.`$$M00LP````R`4`
M`.2`__\4`@```$$M00Y@0YT&G@5(DP24`Y4"E@$"5@K5UM/4W=X.`$$M00L`
M+````/P%```0H___V!````!#+4$.$)T"G@%##J`%`RL$"@X00=[=#@!!+4$+
M````(````"P&``#`L___2`````!!+4$.$)T"G@%.WMT.`$$M````/````%`&
M``#DL___*`$```!!+4$.4)T*G@E#DPB4!T*5!I8%0I<$F`-.F0)6V4D*WMW7
MV-76T]0.`$$M00L``#@```"0!@``S+3__\P!````02U!#D"=")X'0Y,&E`5#
ME026`T(%3P("80K>W=76T]0&3PX`02U!"P```!````#,!@``8+;__PP`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&`=````````#!T`
M```````!`````````!`#`````````0`````````@`P````````$`````````
M*@,````````,`````````.`5````````#0````````",4````````!D`````
M````@/L!```````;``````````@`````````&@````````"(^P$``````!P`
M````````"`````````#U_O]O`````)@"````````!0````````"0"0``````
M``8`````````N`(````````*`````````&$#````````"P`````````8````
M`````!4````````````````````#`````````*#]`0```````@````````"(
M!0```````!0`````````!P`````````7`````````%@0````````!P``````
M``#H#0````````@`````````<`(````````)`````````!@`````````'@``
M```````(`````````/O__V\``````0``"`````#^__]O`````(@-````````
M____;P`````"`````````/#__V\`````\@P```````#Y__]O``````X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````%@`````````6`````````!8`````````%@``
M```````6`````````!8`````````%@`````````6`````````!8`````````
M%@`````````6`````````!8`````````%@`````````6`````````!8`````
M````%@`````````6`````````!8`````````%@`````````6`````````!8`
M````````%@`````````6`````````!8`````````%@`````````6````````
M`!8`````````%@`````````6`````````!8`````````%@`````````6````
M`````!8`````````%@`````````6`````````!8`````````%@`````````6
M`````````!8`````````%@`````````6`````````!8`````````%@``````
M```6`````````!8`````````%@`````````6`````````!8`````````%@``
M```````6`````````!8`````````%@`````````6`````````!8`````````
M%@`````````6`````````!8`````````%@`````````6````````D/L!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````&@``````````````````"``"```````*4$%2+G!M"@``````
M````@%0````````040```````````````````%(```````!@5````````&A4
M````````<%0```````!X5```````````````````2%0```````!05```````
M````````````B%0```````!'0T,Z("A-86=E:6$@,30N,2XP+3`N4D,N,BYM
M9V$Q,"D@,30N,2XP(#(P,C0P-3`S("AP<F5R96QE87-E*0!'0T,Z("A-86=E
M:6$@,30N,BXP+3$N;6=A,3`I(#$T+C(N,```+G-H<W1R=&%B`"YI;G1E<G``
M+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD
M>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````
M````````````````````````````````````````````````````````````
M````````````````"P````$````"`````````#@"````````.`(````````;
M`````````````````````0```````````````````!,````'`````@``````
M``!4`@```````%0"````````)`````````````````````0`````````````
M```````F````!P````(`````````>`(```````!X`@```````"``````````
M```````````$````````````````````-````/;__V\"`````````)@"````
M````F`(````````<``````````4`````````"````````````````````#X`
M```+`````@````````"X`@```````+@"````````V`8````````&`````P``
M``@`````````&`````````!&`````P````(`````````D`D```````"0"0``
M`````&$#```````````````````!````````````````````3@```/___V\"
M`````````/(,````````\@P```````"2``````````4``````````@``````
M```"`````````%L```#^__]O`@````````"(#0```````(@-````````8```
M```````&`````@````@```````````````````!J````!`````(`````````
MZ`T```````#H#0```````'`"````````!0`````````(`````````!@`````
M````=`````0```!"`````````%@0````````6!````````"(!0````````4`
M```5````"``````````8`````````'X````!````!@````````#@%0``````
M`.`5````````&`````````````````````0```````````````````!Y````
M`0````8``````````!8`````````%@```````-`#```````````````````0
M````````````````````A`````$````&```````````:`````````!H`````
M``",-@``````````````````0````````````````````(H````!````!@``
M``````",4````````(Q0````````%`````````````````````0`````````
M``````````"0`````0````(`````````H%````````"@4````````*!!````
M```````````````0````````````````````F`````$````"`````````$"2
M````````0)(````````,`0``````````````````!```````````````````
M`*8````!`````@````````!0DP```````%"3````````X`8`````````````
M``````@```````````````````"P````#@````,`````````@/L!``````"`
M^P````````@````````````````````(``````````@`````````O`````\`
M```#`````````(C[`0``````B/L````````(````````````````````"```
M```````(`````````,@````&`````P````````"0^P$``````)#[````````
M$`(````````&``````````@`````````$`````````#1`````0````,`````
M````H/T!``````"@_0```````&`"```````````````````(``````````@`
M````````U@````$````#`````````````@`````````!``````"(````````
M````````````"````````````````````-P````(`````P````````"(``(`
M`````(@``0``````*`````````````````````@```````````````````#A
M`````0```#````````````````````"(``$``````&,`````````````````
M```!``````````$``````````0````,`````````````````````````ZP`!
E``````#J`````````````````````0``````````````````````
